=========
Changelog
=========

GitHub holds releases, too
==========================

More information can be found on GitHub in the `releases section
<https://github.com/Kwpolska/merge_args/releases>`_.

Version History
===============

0.1.4
    Avoid taking default twice for args in both signatures

0.1.3
    Fix test suite in tarball.

0.1.2
    Python 3.8 support.

0.1.1
    Minor fixes to tests and README.

0.1.0
    Initial release.
